@@ -68,7 +68,9 @@ class WebsocketAgentTransport(AgentTransport):
 
                 async with websockets.connect(
                     f"{self.endpoint_url}?token={token}&instance_id={instance_id}",
-                    ssl=self.ssl_context,
+                    ssl=self.ssl_context
+                    if self.endpoint_url.startswith("wss")
+                    else None,
                 ) as client:
 
                     logger.info("Agent on Websockets connected")
