@@ -1,5 +1,6 @@
 from rekuest.structures.registry import StructureRegistry
 from rekuest.api.schema import TemplateFragment, NodeFragment, aget_template, afind
+from .annotations import ValueRange, convert_value_range
 
 DEFAULT_STRUCTURE_REGISTRY = None
 
@@ -16,4 +17,8 @@ def get_default_structure_registry() -> StructureRegistry:
             NodeFragment, "@rekuest/node", expand=afind
         )
 
+        DEFAULT_STRUCTURE_REGISTRY.register_annotation_converter(
+            ValueRange, convert_value_range
+        )
+
     return DEFAULT_STRUCTURE_REGISTRY
